'use strict';

var crypto = require('crypto'),
    constants = require('../conf/constants');

module.exports = function CryptHelper(secret) {
    return {
        _crypt: function _crypt(text, isEncrypt) {
            var cryptMethod = isEncrypt ? 'createCipher' : 'createDecipher';
            var finalParam = isEncrypt ? 'hex' : 'utf8';
            var cipherArgs = isEncrypt ? [text, 'utf8', 'hex'] : [text, 'hex', 'utf8'];

            var cipher = crypto[cryptMethod](constants.CRYPT_ALGO, secret);
            var result = cipher.update.apply(cipher, cipherArgs);
            result += cipher.final(finalParam);

            return result;
        },
        encrypt: function encrypt(text) {
            return this._crypt(text, true);
        },
        decrypt: function decrypt(text) {
            return this._crypt(text, false);
        },
        stringifyAndEncrypt: function stringifyAndEncrypt(data, withEncryption) {
            var stringifiedData = JSON.stringify(data);

            if (withEncryption) {
                return this.encrypt(stringifiedData);
            } else {
                return stringifiedData;
            }
        },
        decryptAndParse: function decryptAndParse(msg, withEncryption) {
            if (withEncryption) {
                msg = this.decrypt(msg);
            }
            return JSON.parse(msg);
        }
    };
};